fnss.topologies.parsers.parse_caida_as_relationships — FNSS 0.5.0 documentation

### Navigation

- index
- modules |
- modules |
- next |
- previous |
- FNSS 0.5.0 documentation »
- API Reference »
- Functions »

# fnss.topologies.parsers.parse_caida_as_relationships

`parse_caida_as_relationships`(path)

  Parse a topology from the CAIDA AS relationships dataset

  Parameters : | path : str The path to the CAIDA AS relationships file
  Returns : | topology : DirectedTopology

  Notes

  The node names of the returned topology are the the ASN of the of the AS they represent and edges are annotated with the relationship between ASes they connect. The relationship values can either be customer, peer or sibling.

### Navigation

- index
- modules |
- modules |
- next |
- previous |
- FNSS 0.5.0 documentation »
- API Reference »
- Functions »